#!/usr/bin/env python
"""SNAPbuild exe wrapper"""

import os
import platform
import subprocess
import sys

from distutils.sysconfig import get_python_lib

################################################################
# Are we snapbuild (*nix) or snapbuild.exe (Win)?
EXT = ''
if platform.system().lower().startswith('win'):
    EXT = '.exe'

EXE_NAME = 'snapbuild' + EXT

SNAPBUILD_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)), EXE_NAME)


def call(args=None, stderr=None):
    """Wrapper for SNAPbuild that includes site-pkgs by default
    Have to wrap it because pulling site-packages from within
    the executable would get the wrong site-packages...
    """

    if args is None:
        args = sys.argv

    addl_args = ['-I', '%s' % get_python_lib()]
    call_args = [SNAPBUILD_PATH] + args[1:] + addl_args

    return subprocess.check_output(call_args, stderr=stderr)


def _write_output(output):
    for line in output.split('\n'):
        print line


def main(args=None):
    """Wrapper for SNAPbuild that includes site-pkgs by default
    Have to wrap it because pulling site-packages from within
    the executable would get the wrong site-packages...
    """

    try:
        output = call(args)
        _write_output(output)
    except subprocess.CalledProcessError as e:
        _write_output(e.output)
        exit(e.returncode)
    except:
        exit(1)
    else:
        exit(0)

if __name__ == '__main__':
    main(sys.argv)
